# Welcome!

Thanks for participating in the Ragna community! As an early-stage open source project,
we rely on community members to help improve Ragna and we're grateful for your interest.

## Code of Conduct

All Ragna community spaces including discussions on GitHub and audio/video meetings are
covered by the
[Quansight Repository Code of Conduct](https://github.com/Quansight/.github/blob/master/CODE_OF_CONDUCT.md)
to create an welcoming environment for everyone.

## Support

If you have questions about how to use Ragna, open a discussion on the
[GitHub Discussions forum](https://github.com/Quansight/ragna/discussions) to reach the
development team.

## Contribute

We welcome all kinds of contributions including but not limited to advocacy, bug fixes,
community management, design, documentation, fundraising, new features, testing,
triage,and user support. If you're interested in contributing, reach out to us on the
[issue tracker](https://github.com/Quansight/ragna/issues)!

[Learn to contribute code and documentation →](contribute.md)

## Governance

All project decisions are made by the Ragna Development Team, and typically involve a
discussion (during meetings or through an RFD) followed by a vote.

The current Ragna development team consists of members from Quansight LLC, who supported
the initial development of Ragna. Community members with valuable contributions to the
projects can be nominated and added to the Ragna Development Team.
